/***************************************************************************
 *   Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#include "AboutDialog.h"

#include <QString>
#include <QStringList>
#include <QProcess>
#include <QRegExp>
#include <QList>
#include <QNetworkInterface>
#include <QHostInfo>

static QString getSynergyVersion(const QString& app)
{
#if !defined(Q_OS_WIN)
	QProcess process;
	process.start(app, QStringList() << "--version");

	process.setReadChannel(QProcess::StandardError);
	if (!process.waitForStarted() || !process.waitForFinished())
		return QObject::tr("(unknown)");

	QRegExp rx("synergy[cs] ([\\d\\.]+)");
	if (rx.indexIn(QString(process.readLine())) != -1)
		return rx.cap(1);
#else
	Q_UNUSED(app);
#endif

	return QObject::tr("(unknown)");
}

static QString getIPAddress()
{
	QList<QHostAddress> addresses = QNetworkInterface::allAddresses();

	for (int i = 0; i < addresses.size(); i++)
		if (addresses[i].protocol() == QAbstractSocket::IPv4Protocol && addresses[i] != QHostAddress(QHostAddress::LocalHost))
			return addresses[i].toString();

	return QObject::tr("(unknown)");
}

AboutDialog::AboutDialog(QWidget* parent, const QString& synergyApp) :
	QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint),
	Ui::AboutDialogBase()
{
	setupUi(this);

	m_pLabelSynergyVersion->setText(getSynergyVersion(synergyApp));
	m_pLabelHostname->setText(QHostInfo::localHostName());
	m_pLabelIPAddress->setText(getIPAddress());
}

