/***************************************************************************
 *   Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#include "ActionDialog.h"

#include "Hotkey.h"
#include "Action.h"
#include "ServerConfig.h"
#include "KeySequence.h"

#include <QButtonGroup>
#include <QRadioButton>
#include <QListWidgetItem>
#include <QDebug>

ActionDialog::ActionDialog(QWidget* parent, ServerConfig& config, Hotkey& hotkey, Action& action) :
	QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint),
	Ui::ActionDialogBase(),
	m_ServerConfig(config),
	m_Hotkey(hotkey),
	m_Action(action),
	m_pButtonGroupType(new QButtonGroup(this))
{
	setupUi(this);

	// work around Qt Designer's lack of a QButtonGroup; we need it to get
	// at the button id of the checked radio button
	QRadioButton* const typeButtons[] = { m_pRadioPress, m_pRadioRelease, m_pRadioPressAndRelease, m_pRadioSwitchToScreen, m_pRadioSwitchInDirection, m_pRadioLockCursorToScreen };

	for (unsigned int i = 0; i < sizeof(typeButtons) / sizeof(typeButtons[0]); i++)
		m_pButtonGroupType->addButton(typeButtons[i], i);

	connect(m_pButtonGroupType, SIGNAL(buttonClicked(int)), SLOT(updateEnabled(int)));

	m_pKeySequenceWidgetHotkey->setText(m_Action.keySequence().toString());
	m_pKeySequenceWidgetHotkey->setKeySequence(m_Action.keySequence());
	m_pButtonGroupType->button(m_Action.type())->setChecked(true);
	m_pComboSwitchInDirection->setCurrentIndex(m_Action.switchDirection());
	m_pComboLockCursorToScreen->setCurrentIndex(m_Action.lockCursorMode());
	m_pRadioHotkeyReleased->setChecked(m_Action.activeOnRelease());
	m_pRadioHotkeyPressed->setChecked(!m_Action.activeOnRelease());
	m_pGroupBoxScreens->setChecked(m_Action.haveScreens());

	int idx = 0;
	foreach(const Screen& screen, serverConfig().screens())
		if (!screen.isNull())
		{
			QListWidgetItem* pListItem = new QListWidgetItem(screen.name());
			m_pListScreens->addItem(pListItem);
			if (m_Action.typeScreenNames().indexOf(screen.name()) != -1)
				m_pListScreens->setCurrentItem(pListItem);

			m_pComboSwitchToScreen->addItem(screen.name());
			if (screen.name() == m_Action.switchScreenName())
				m_pComboSwitchToScreen->setCurrentIndex(idx);

			idx++;
		}

	updateEnabled();
}

void ActionDialog::accept()
{
	m_Action.setKeySequence(sequenceWidget()->keySequence());
	m_Action.setType(m_pButtonGroupType->checkedId());
	m_Action.setHaveScreens(m_pGroupBoxScreens->isChecked());

	m_Action.typeScreenNames().clear();
	foreach(const QListWidgetItem* pItem, m_pListScreens->selectedItems())
		m_Action.typeScreenNames().append(pItem->text());

	m_Action.setSwitchScreenName(m_pComboSwitchToScreen->currentText());
	m_Action.setSwitchDirection(m_pComboSwitchInDirection->currentIndex());
	m_Action.setLockCursorMode(m_pComboLockCursorToScreen->currentIndex());
	m_Action.setActiveOnRelease(m_pRadioHotkeyReleased->isChecked());

	QDialog::accept();
}

void ActionDialog::on_m_pKeySequenceWidgetHotkey_keySequenceChanged()
{
	m_pGroupBoxScreens->setEnabled(!sequenceWidget()->keySequence().isMouseButton());
	m_pListScreens->setEnabled(!sequenceWidget()->keySequence().isMouseButton());
	updateEnabled();
}

void ActionDialog::updateEnabled(int)
{
	const bool enableHotkeys = m_pButtonGroupType->checkedId() >= 0 && m_pButtonGroupType->checkedId() < 3;
	m_pKeySequenceWidgetHotkey->setEnabled(enableHotkeys);
	m_pGroupBoxScreens->setEnabled(enableHotkeys);

	const bool enableOkButton = !enableHotkeys || sequenceWidget()->valid();
	m_pButtonBox->button(QDialogButtonBox::Ok)->setEnabled(enableOkButton);
}

