/***************************************************************************
 *   Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#include "Hotkey.h"

#include <QSettings>
#include <QTextStream>

Hotkey::Hotkey() :
	m_KeySequence(),
	m_Actions()
{
}

QString Hotkey::text() const
{
	return QString("%1(%2)").arg(keySequence().isMouseButton() ? "mousebutton" : "keystroke").arg(keySequence().toString());
}

void Hotkey::loadSettings(QSettings& settings)
{
	keySequence().loadSettings(settings);

	actions().clear();
	int num = settings.beginReadArray("actions");
	for (int i = 0; i < num; i++)
	{
		settings.setArrayIndex(i);
		Action a;
		a.loadSettings(settings);
		actions().append(a);
	}

	settings.endArray();
}

void Hotkey::saveSettings(QSettings& settings) const
{
	keySequence().saveSettings(settings);

	settings.beginWriteArray("actions");
	for (int i = 0; i < actions().size(); i++)
	{
		settings.setArrayIndex(i);
		actions()[i].saveSettings(settings);
	}
	settings.endArray();
}

QTextStream& operator<<(QTextStream& outStream, const Hotkey& hotkey)
{
	for (int i = 0; i < hotkey.actions().size(); i++)
		outStream << "\t" << hotkey.text() << " = " << hotkey.actions()[i] << endl;

	return outStream;
}
